@@ -13,6 +13,7 @@ pub use chars::is_whitespace;
 pub use doc::Document;
 pub use doc::{Declaration, Encoding, Version};
 pub use element::Element;
+pub use index::Index;
 pub(crate) use name::Name;
 pub use node::{Misc, Node};
 pub use pi::Pi;
@@ -28,6 +29,7 @@ mod chars;
 mod doc;
 mod element;
 pub mod error;
+mod index;
 mod name;
 mod node;
 pub(crate) mod ord_map;
